embassy-stm32

Crates

git

Versions

stm32u5f9zi

Flavors

Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 230 fields pub PA0: Peri<'static, PA0>, pub PA1: Peri<'static, PA1>, pub PA2: Peri<'static, PA2>, pub PA3: Peri<'static, PA3>, pub PA4: Peri<'static, PA4>, pub PA5: Peri<'static, PA5>, pub PA6: Peri<'static, PA6>, pub PA7: Peri<'static, PA7>, pub PA8: Peri<'static, PA8>, pub PA9: Peri<'static, PA9>, pub PA10: Peri<'static, PA10>, pub PA11: Peri<'static, PA11>, pub PA12: Peri<'static, PA12>, pub PA13: Peri<'static, PA13>, pub PA14: Peri<'static, PA14>, pub PA15: Peri<'static, PA15>, pub PB0: Peri<'static, PB0>, pub PB1: Peri<'static, PB1>, pub PB2: Peri<'static, PB2>, pub PB3: Peri<'static, PB3>, pub PB4: Peri<'static, PB4>, pub PB5: Peri<'static, PB5>, pub PB6: Peri<'static, PB6>, pub PB7: Peri<'static, PB7>, pub PB8: Peri<'static, PB8>, pub PB9: Peri<'static, PB9>, pub PB10: Peri<'static, PB10>, pub PB11: Peri<'static, PB11>, pub PB13: Peri<'static, PB13>, pub PB14: Peri<'static, PB14>, pub PB15: Peri<'static, PB15>, pub PC0: Peri<'static, PC0>, pub PC1: Peri<'static, PC1>, pub PC2: Peri<'static, PC2>, pub PC3: Peri<'static, PC3>, pub PC6: Peri<'static, PC6>, pub PC7: Peri<'static, PC7>, pub PC8: Peri<'static, PC8>, pub PC9: Peri<'static, PC9>, pub PC10: Peri<'static, PC10>, pub PC11: Peri<'static, PC11>, pub PC12: Peri<'static, PC12>, pub PC13: Peri<'static, PC13>, pub PC14: Peri<'static, PC14>, pub PC15: Peri<'static, PC15>, pub PD0: Peri<'static, PD0>, pub PD1: Peri<'static, PD1>, pub PD2: Peri<'static, PD2>, pub PD3: Peri<'static, PD3>, pub PD4: Peri<'static, PD4>, pub PD5: Peri<'static, PD5>, pub PD6: Peri<'static, PD6>, pub PD7: Peri<'static, PD7>, pub PD8: Peri<'static, PD8>, pub PD9: Peri<'static, PD9>, pub PD10: Peri<'static, PD10>, pub PD11: Peri<'static, PD11>, pub PD12: Peri<'static, PD12>, pub PD13: Peri<'static, PD13>, pub PD14: Peri<'static, PD14>, pub PD15: Peri<'static, PD15>, pub PE0: Peri<'static, PE0>, pub PE2: Peri<'static, PE2>, pub PE3: Peri<'static, PE3>, pub PE4: Peri<'static, PE4>, pub PE5: Peri<'static, PE5>, pub PE6: Peri<'static, PE6>, pub PE7: Peri<'static, PE7>, pub PE8: Peri<'static, PE8>, pub PE9: Peri<'static, PE9>, pub PE10: Peri<'static, PE10>, pub PE11: Peri<'static, PE11>, pub PE12: Peri<'static, PE12>, pub PE13: Peri<'static, PE13>, pub PE14: Peri<'static, PE14>, pub PE15: Peri<'static, PE15>, pub PF0: Peri<'static, PF0>, pub PF1: Peri<'static, PF1>, pub PF2: Peri<'static, PF2>, pub PG0: Peri<'static, PG0>, pub PG1: Peri<'static, PG1>, pub PG9: Peri<'static, PG9>, pub PG10: Peri<'static, PG10>, pub PG12: Peri<'static, PG12>, pub PG13: Peri<'static, PG13>, pub PG14: Peri<'static, PG14>, pub PG15: Peri<'static, PG15>, pub PH0: Peri<'static, PH0>, pub PH1: Peri<'static, PH1>, pub PH3: Peri<'static, PH3>, pub PH9: Peri<'static, PH9>, pub PH10: Peri<'static, PH10>, pub PH11: Peri<'static, PH11>, pub PH12: Peri<'static, PH12>, pub PH13: Peri<'static, PH13>, pub PH14: Peri<'static, PH14>, pub PH15: Peri<'static, PH15>, pub PI0: Peri<'static, PI0>, pub PI1: Peri<'static, PI1>, pub PI2: Peri<'static, PI2>, pub PI3: Peri<'static, PI3>, pub ADC1: Peri<'static, ADC1>, pub ADC12_COMMON: Peri<'static, ADC12_COMMON>, pub ADC2: Peri<'static, ADC2>, pub ADC4: Peri<'static, ADC4>, pub ADC4_COMMON: Peri<'static, ADC4_COMMON>, pub ADF1: Peri<'static, ADF1>, pub COMP1: Peri<'static, COMP1>, pub COMP2: Peri<'static, COMP2>, pub CORDIC: Peri<'static, CORDIC>, pub CRC: Peri<'static, CRC>, pub CRS: Peri<'static, CRS>, pub DAC1: Peri<'static, DAC1>, pub DBGMCU: Peri<'static, DBGMCU>, pub DCACHE1: Peri<'static, DCACHE1>, pub DCACHE2: Peri<'static, DCACHE2>, pub DCMI: Peri<'static, DCMI>, pub DLYB_OCTOSPI1: Peri<'static, DLYB_OCTOSPI1>, pub DLYB_OCTOSPI2: Peri<'static, DLYB_OCTOSPI2>, pub DLYB_SDMMC1: Peri<'static, DLYB_SDMMC1>, pub DLYB_SDMMC2: Peri<'static, DLYB_SDMMC2>, pub DMA2D: Peri<'static, DMA2D>, pub DSIHOST: Peri<'static, DSIHOST>, pub FLASH: Peri<'static, FLASH>, pub FMAC: Peri<'static, FMAC>, pub GFXMMU: Peri<'static, GFXMMU>, pub GPDMA1: Peri<'static, GPDMA1>, pub GTZC: Peri<'static, GTZC>, pub GTZC_MPCBB1: Peri<'static, GTZC_MPCBB1>, pub GTZC_MPCBB2: Peri<'static, GTZC_MPCBB2>, pub GTZC_MPCBB3: Peri<'static, GTZC_MPCBB3>, pub GTZC_MPCBB6: Peri<'static, GTZC_MPCBB6>, pub GTZC_TZIC: Peri<'static, GTZC_TZIC>, pub GTZC_TZSC: Peri<'static, GTZC_TZSC>, pub HASH: Peri<'static, HASH>, pub HSPI1: Peri<'static, HSPI1>, pub I2C1: Peri<'static, I2C1>, pub I2C2: Peri<'static, I2C2>, pub I2C3: Peri<'static, I2C3>, pub I2C4: Peri<'static, I2C4>, pub I2C5: Peri<'static, I2C5>, pub I2C6: Peri<'static, I2C6>, pub ICACHE: Peri<'static, ICACHE>, pub IWDG: Peri<'static, IWDG>, pub JPEG: Peri<'static, JPEG>, pub LPDMA1: Peri<'static, LPDMA1>, pub LPTIM1: Peri<'static, LPTIM1>, pub LPTIM2: Peri<'static, LPTIM2>, pub LPTIM3: Peri<'static, LPTIM3>, pub LPTIM4: Peri<'static, LPTIM4>, pub LPUART1: Peri<'static, LPUART1>, pub LTDC: Peri<'static, LTDC>, pub OCTOSPI1: Peri<'static, OCTOSPI1>, pub OCTOSPIM: Peri<'static, OCTOSPIM>, pub OPAMP1: Peri<'static, OPAMP1>, pub OPAMP2: Peri<'static, OPAMP2>, pub PSSI: Peri<'static, PSSI>, pub PWR: Peri<'static, PWR>, pub RAMCFG: Peri<'static, RAMCFG>, pub MCO: Peri<'static, MCO>, pub RCC: Peri<'static, RCC>, pub RNG: Peri<'static, RNG>, pub RTC: Peri<'static, RTC>, pub SAI1: Peri<'static, SAI1>, pub SAI2: Peri<'static, SAI2>, pub SDMMC1: Peri<'static, SDMMC1>, pub SDMMC2: Peri<'static, SDMMC2>, pub SPI1: Peri<'static, SPI1>, pub SPI2: Peri<'static, SPI2>, pub SPI3: Peri<'static, SPI3>, pub SYSCFG: Peri<'static, SYSCFG>, pub TAMP: Peri<'static, TAMP>, pub TIM1: Peri<'static, TIM1>, pub TIM16: Peri<'static, TIM16>, pub TIM17: Peri<'static, TIM17>, pub TIM2: Peri<'static, TIM2>, pub TIM3: Peri<'static, TIM3>, pub TIM4: Peri<'static, TIM4>, pub TIM5: Peri<'static, TIM5>, pub TIM6: Peri<'static, TIM6>, pub TIM7: Peri<'static, TIM7>, pub TIM8: Peri<'static, TIM8>, pub TSC: Peri<'static, TSC>, pub UART4: Peri<'static, UART4>, pub UART5: Peri<'static, UART5>, pub UCPD1: Peri<'static, UCPD1>, pub UID: Peri<'static, UID>, pub USART1: Peri<'static, USART1>, pub USART2: Peri<'static, USART2>, pub USART3: Peri<'static, USART3>, pub USART6: Peri<'static, USART6>, pub USB_OTG_HS: Peri<'static, USB_OTG_HS>, pub VREFBUF: Peri<'static, VREFBUF>, pub WWDG: Peri<'static, WWDG>, pub EXTI0: Peri<'static, EXTI0>, pub EXTI1: Peri<'static, EXTI1>, pub EXTI2: Peri<'static, EXTI2>, pub EXTI3: Peri<'static, EXTI3>, pub EXTI4: Peri<'static, EXTI4>, pub EXTI5: Peri<'static, EXTI5>, pub EXTI6: Peri<'static, EXTI6>, pub EXTI7: Peri<'static, EXTI7>, pub EXTI8: Peri<'static, EXTI8>, pub EXTI9: Peri<'static, EXTI9>, pub EXTI10: Peri<'static, EXTI10>, pub EXTI11: Peri<'static, EXTI11>, pub EXTI12: Peri<'static, EXTI12>, pub EXTI13: Peri<'static, EXTI13>, pub EXTI14: Peri<'static, EXTI14>, pub EXTI15: Peri<'static, EXTI15>, pub LPDMA1_CH0: Peri<'static, LPDMA1_CH0>, pub LPDMA1_CH1: Peri<'static, LPDMA1_CH1>, pub LPDMA1_CH2: Peri<'static, LPDMA1_CH2>, pub LPDMA1_CH3: Peri<'static, LPDMA1_CH3>, pub GPDMA1_CH0: Peri<'static, GPDMA1_CH0>, pub GPDMA1_CH1: Peri<'static, GPDMA1_CH1>, pub GPDMA1_CH2: Peri<'static, GPDMA1_CH2>, pub GPDMA1_CH3: Peri<'static, GPDMA1_CH3>, pub GPDMA1_CH4: Peri<'static, GPDMA1_CH4>, pub GPDMA1_CH5: Peri<'static, GPDMA1_CH5>, pub GPDMA1_CH6: Peri<'static, GPDMA1_CH6>, pub GPDMA1_CH7: Peri<'static, GPDMA1_CH7>, pub GPDMA1_CH8: Peri<'static, GPDMA1_CH8>, pub GPDMA1_CH9: Peri<'static, GPDMA1_CH9>, pub GPDMA1_CH10: Peri<'static, GPDMA1_CH10>, pub GPDMA1_CH11: Peri<'static, GPDMA1_CH11>, pub GPDMA1_CH12: Peri<'static, GPDMA1_CH12>, pub GPDMA1_CH13: Peri<'static, GPDMA1_CH13>, pub GPDMA1_CH14: Peri<'static, GPDMA1_CH14>, pub GPDMA1_CH15: Peri<'static, GPDMA1_CH15>,
}
Struct containing all the peripheral singletons.

To obtain the peripherals, you must initialize the HAL, by calling crate::init.

Fields

PA0: Peri<'static, PA0>

PA0 peripheral

PA1: Peri<'static, PA1>

PA1 peripheral

PA2: Peri<'static, PA2>

PA2 peripheral

PA3: Peri<'static, PA3>

PA3 peripheral

PA4: Peri<'static, PA4>

PA4 peripheral

PA5: Peri<'static, PA5>

PA5 peripheral

PA6: Peri<'static, PA6>

PA6 peripheral

PA7: Peri<'static, PA7>

PA7 peripheral

PA8: Peri<'static, PA8>

PA8 peripheral

PA9: Peri<'static, PA9>

PA9 peripheral

PA10: Peri<'static, PA10>

PA10 peripheral

PA11: Peri<'static, PA11>

PA11 peripheral

PA12: Peri<'static, PA12>

PA12 peripheral

PA13: Peri<'static, PA13>

PA13 peripheral

PA14: Peri<'static, PA14>

PA14 peripheral

PA15: Peri<'static, PA15>

PA15 peripheral

PB0: Peri<'static, PB0>

PB0 peripheral

PB1: Peri<'static, PB1>

PB1 peripheral

PB2: Peri<'static, PB2>

PB2 peripheral

PB3: Peri<'static, PB3>

PB3 peripheral

PB4: Peri<'static, PB4>

PB4 peripheral

PB5: Peri<'static, PB5>

PB5 peripheral

PB6: Peri<'static, PB6>

PB6 peripheral

PB7: Peri<'static, PB7>

PB7 peripheral

PB8: Peri<'static, PB8>

PB8 peripheral

PB9: Peri<'static, PB9>

PB9 peripheral

PB10: Peri<'static, PB10>

PB10 peripheral

PB11: Peri<'static, PB11>

PB11 peripheral

PB13: Peri<'static, PB13>

PB13 peripheral

PB14: Peri<'static, PB14>

PB14 peripheral

PB15: Peri<'static, PB15>

PB15 peripheral

PC0: Peri<'static, PC0>

PC0 peripheral

PC1: Peri<'static, PC1>

PC1 peripheral

PC2: Peri<'static, PC2>

PC2 peripheral

PC3: Peri<'static, PC3>

PC3 peripheral

PC6: Peri<'static, PC6>

PC6 peripheral

PC7: Peri<'static, PC7>

PC7 peripheral

PC8: Peri<'static, PC8>

PC8 peripheral

PC9: Peri<'static, PC9>

PC9 peripheral

PC10: Peri<'static, PC10>

PC10 peripheral

PC11: Peri<'static, PC11>

PC11 peripheral

PC12: Peri<'static, PC12>

PC12 peripheral

PC13: Peri<'static, PC13>

PC13 peripheral

PC14: Peri<'static, PC14>

PC14 peripheral

PC15: Peri<'static, PC15>

PC15 peripheral

PD0: Peri<'static, PD0>

PD0 peripheral

PD1: Peri<'static, PD1>

PD1 peripheral

PD2: Peri<'static, PD2>

PD2 peripheral

PD3: Peri<'static, PD3>

PD3 peripheral

PD4: Peri<'static, PD4>

PD4 peripheral

PD5: Peri<'static, PD5>

PD5 peripheral

PD6: Peri<'static, PD6>

PD6 peripheral

PD7: Peri<'static, PD7>

PD7 peripheral

PD8: Peri<'static, PD8>

PD8 peripheral

PD9: Peri<'static, PD9>

PD9 peripheral

PD10: Peri<'static, PD10>

PD10 peripheral

PD11: Peri<'static, PD11>

PD11 peripheral

PD12: Peri<'static, PD12>

PD12 peripheral

PD13: Peri<'static, PD13>

PD13 peripheral

PD14: Peri<'static, PD14>

PD14 peripheral

PD15: Peri<'static, PD15>

PD15 peripheral

PE0: Peri<'static, PE0>

PE0 peripheral

PE2: Peri<'static, PE2>

PE2 peripheral

PE3: Peri<'static, PE3>

PE3 peripheral

PE4: Peri<'static, PE4>

PE4 peripheral

PE5: Peri<'static, PE5>

PE5 peripheral

PE6: Peri<'static, PE6>

PE6 peripheral

PE7: Peri<'static, PE7>

PE7 peripheral

PE8: Peri<'static, PE8>

PE8 peripheral

PE9: Peri<'static, PE9>

PE9 peripheral

PE10: Peri<'static, PE10>

PE10 peripheral

PE11: Peri<'static, PE11>

PE11 peripheral

PE12: Peri<'static, PE12>

PE12 peripheral

PE13: Peri<'static, PE13>

PE13 peripheral

PE14: Peri<'static, PE14>

PE14 peripheral

PE15: Peri<'static, PE15>

PE15 peripheral

PF0: Peri<'static, PF0>

PF0 peripheral

PF1: Peri<'static, PF1>

PF1 peripheral

PF2: Peri<'static, PF2>

PF2 peripheral

PG0: Peri<'static, PG0>

PG0 peripheral

PG1: Peri<'static, PG1>

PG1 peripheral

PG9: Peri<'static, PG9>

PG9 peripheral

PG10: Peri<'static, PG10>

PG10 peripheral

PG12: Peri<'static, PG12>

PG12 peripheral

PG13: Peri<'static, PG13>

PG13 peripheral

PG14: Peri<'static, PG14>

PG14 peripheral

PG15: Peri<'static, PG15>

PG15 peripheral

PH0: Peri<'static, PH0>

PH0 peripheral

PH1: Peri<'static, PH1>

PH1 peripheral

PH3: Peri<'static, PH3>

PH3 peripheral

PH9: Peri<'static, PH9>

PH9 peripheral

PH10: Peri<'static, PH10>

PH10 peripheral

PH11: Peri<'static, PH11>

PH11 peripheral

PH12: Peri<'static, PH12>

PH12 peripheral

PH13: Peri<'static, PH13>

PH13 peripheral

PH14: Peri<'static, PH14>

PH14 peripheral

PH15: Peri<'static, PH15>

PH15 peripheral

PI0: Peri<'static, PI0>

PI0 peripheral

PI1: Peri<'static, PI1>

PI1 peripheral

PI2: Peri<'static, PI2>

PI2 peripheral

PI3: Peri<'static, PI3>

PI3 peripheral

ADC1: Peri<'static, ADC1>

ADC1 peripheral

ADC12_COMMON: Peri<'static, ADC12_COMMON>

ADC12_COMMON peripheral

ADC2: Peri<'static, ADC2>

ADC2 peripheral

ADC4: Peri<'static, ADC4>

ADC4 peripheral

ADC4_COMMON: Peri<'static, ADC4_COMMON>

ADC4_COMMON peripheral

ADF1: Peri<'static, ADF1>

ADF1 peripheral

COMP1: Peri<'static, COMP1>

COMP1 peripheral

COMP2: Peri<'static, COMP2>

COMP2 peripheral

CORDIC: Peri<'static, CORDIC>

CORDIC peripheral

CRC: Peri<'static, CRC>

CRC peripheral

CRS: Peri<'static, CRS>

CRS peripheral

DAC1: Peri<'static, DAC1>

DAC1 peripheral

DBGMCU: Peri<'static, DBGMCU>

DBGMCU peripheral

DCACHE1: Peri<'static, DCACHE1>

DCACHE1 peripheral

DCACHE2: Peri<'static, DCACHE2>

DCACHE2 peripheral

DCMI: Peri<'static, DCMI>

DCMI peripheral

DLYB_OCTOSPI1: Peri<'static, DLYB_OCTOSPI1>

DLYB_OCTOSPI1 peripheral

DLYB_OCTOSPI2: Peri<'static, DLYB_OCTOSPI2>

DLYB_OCTOSPI2 peripheral

DLYB_SDMMC1: Peri<'static, DLYB_SDMMC1>

DLYB_SDMMC1 peripheral

DLYB_SDMMC2: Peri<'static, DLYB_SDMMC2>

DLYB_SDMMC2 peripheral

DMA2D: Peri<'static, DMA2D>

DMA2D peripheral

DSIHOST: Peri<'static, DSIHOST>

DSIHOST peripheral

FLASH: Peri<'static, FLASH>

FLASH peripheral

FMAC: Peri<'static, FMAC>

FMAC peripheral

GFXMMU: Peri<'static, GFXMMU>

GFXMMU peripheral

GPDMA1: Peri<'static, GPDMA1>

GPDMA1 peripheral

GTZC: Peri<'static, GTZC>

GTZC peripheral

GTZC_MPCBB1: Peri<'static, GTZC_MPCBB1>

GTZC_MPCBB1 peripheral

GTZC_MPCBB2: Peri<'static, GTZC_MPCBB2>

GTZC_MPCBB2 peripheral

GTZC_MPCBB3: Peri<'static, GTZC_MPCBB3>

GTZC_MPCBB3 peripheral

GTZC_MPCBB6: Peri<'static, GTZC_MPCBB6>

GTZC_MPCBB6 peripheral

GTZC_TZIC: Peri<'static, GTZC_TZIC>

GTZC_TZIC peripheral

GTZC_TZSC: Peri<'static, GTZC_TZSC>

GTZC_TZSC peripheral

HASH: Peri<'static, HASH>

HASH peripheral

HSPI1: Peri<'static, HSPI1>

HSPI1 peripheral

I2C1: Peri<'static, I2C1>

I2C1 peripheral

I2C2: Peri<'static, I2C2>

I2C2 peripheral

I2C3: Peri<'static, I2C3>

I2C3 peripheral

I2C4: Peri<'static, I2C4>

I2C4 peripheral

I2C5: Peri<'static, I2C5>

I2C5 peripheral

I2C6: Peri<'static, I2C6>

I2C6 peripheral

ICACHE: Peri<'static, ICACHE>

ICACHE peripheral

IWDG: Peri<'static, IWDG>

IWDG peripheral

JPEG: Peri<'static, JPEG>

JPEG peripheral

LPDMA1: Peri<'static, LPDMA1>

LPDMA1 peripheral

LPTIM1: Peri<'static, LPTIM1>

LPTIM1 peripheral

LPTIM2: Peri<'static, LPTIM2>

LPTIM2 peripheral

LPTIM3: Peri<'static, LPTIM3>

LPTIM3 peripheral

LPTIM4: Peri<'static, LPTIM4>

LPTIM4 peripheral

LPUART1: Peri<'static, LPUART1>

LPUART1 peripheral

LTDC: Peri<'static, LTDC>

LTDC peripheral

OCTOSPI1: Peri<'static, OCTOSPI1>

OCTOSPI1 peripheral

OCTOSPIM: Peri<'static, OCTOSPIM>

OCTOSPIM peripheral

OPAMP1: Peri<'static, OPAMP1>

OPAMP1 peripheral

OPAMP2: Peri<'static, OPAMP2>

OPAMP2 peripheral

PSSI: Peri<'static, PSSI>

PSSI peripheral

PWR: Peri<'static, PWR>

PWR peripheral

RAMCFG: Peri<'static, RAMCFG>

RAMCFG peripheral

MCO: Peri<'static, MCO>

MCO peripheral

RCC: Peri<'static, RCC>

RCC peripheral

RNG: Peri<'static, RNG>

RNG peripheral

RTC: Peri<'static, RTC>

RTC peripheral

SAI1: Peri<'static, SAI1>

SAI1 peripheral

SAI2: Peri<'static, SAI2>

SAI2 peripheral

SDMMC1: Peri<'static, SDMMC1>

SDMMC1 peripheral

SDMMC2: Peri<'static, SDMMC2>

SDMMC2 peripheral

SPI1: Peri<'static, SPI1>

SPI1 peripheral

SPI2: Peri<'static, SPI2>

SPI2 peripheral

SPI3: Peri<'static, SPI3>

SPI3 peripheral

SYSCFG: Peri<'static, SYSCFG>

SYSCFG peripheral

TAMP: Peri<'static, TAMP>

TAMP peripheral

TIM1: Peri<'static, TIM1>

TIM1 peripheral

TIM16: Peri<'static, TIM16>

TIM16 peripheral

TIM17: Peri<'static, TIM17>

TIM17 peripheral

TIM2: Peri<'static, TIM2>

TIM2 peripheral

TIM3: Peri<'static, TIM3>

TIM3 peripheral

TIM4: Peri<'static, TIM4>

TIM4 peripheral

TIM5: Peri<'static, TIM5>

TIM5 peripheral

TIM6: Peri<'static, TIM6>

TIM6 peripheral

TIM7: Peri<'static, TIM7>

TIM7 peripheral

TIM8: Peri<'static, TIM8>

TIM8 peripheral

TSC: Peri<'static, TSC>

TSC peripheral

UART4: Peri<'static, UART4>

UART4 peripheral

UART5: Peri<'static, UART5>

UART5 peripheral

UCPD1: Peri<'static, UCPD1>

UCPD1 peripheral

UID: Peri<'static, UID>

UID peripheral

USART1: Peri<'static, USART1>

USART1 peripheral

USART2: Peri<'static, USART2>

USART2 peripheral

USART3: Peri<'static, USART3>

USART3 peripheral

USART6: Peri<'static, USART6>

USART6 peripheral

USB_OTG_HS: Peri<'static, USB_OTG_HS>

USB_OTG_HS peripheral

VREFBUF: Peri<'static, VREFBUF>

VREFBUF peripheral

WWDG: Peri<'static, WWDG>

WWDG peripheral

EXTI0: Peri<'static, EXTI0>

EXTI0 peripheral

EXTI1: Peri<'static, EXTI1>

EXTI1 peripheral

EXTI2: Peri<'static, EXTI2>

EXTI2 peripheral

EXTI3: Peri<'static, EXTI3>

EXTI3 peripheral

EXTI4: Peri<'static, EXTI4>

EXTI4 peripheral

EXTI5: Peri<'static, EXTI5>

EXTI5 peripheral

EXTI6: Peri<'static, EXTI6>

EXTI6 peripheral

EXTI7: Peri<'static, EXTI7>

EXTI7 peripheral

EXTI8: Peri<'static, EXTI8>

EXTI8 peripheral

EXTI9: Peri<'static, EXTI9>

EXTI9 peripheral

EXTI10: Peri<'static, EXTI10>

EXTI10 peripheral

EXTI11: Peri<'static, EXTI11>

EXTI11 peripheral

EXTI12: Peri<'static, EXTI12>

EXTI12 peripheral

EXTI13: Peri<'static, EXTI13>

EXTI13 peripheral

EXTI14: Peri<'static, EXTI14>

EXTI14 peripheral

EXTI15: Peri<'static, EXTI15>

EXTI15 peripheral

LPDMA1_CH0: Peri<'static, LPDMA1_CH0>

LPDMA1_CH0 peripheral

LPDMA1_CH1: Peri<'static, LPDMA1_CH1>

LPDMA1_CH1 peripheral

LPDMA1_CH2: Peri<'static, LPDMA1_CH2>

LPDMA1_CH2 peripheral

LPDMA1_CH3: Peri<'static, LPDMA1_CH3>

LPDMA1_CH3 peripheral

GPDMA1_CH0: Peri<'static, GPDMA1_CH0>

GPDMA1_CH0 peripheral

GPDMA1_CH1: Peri<'static, GPDMA1_CH1>

GPDMA1_CH1 peripheral

GPDMA1_CH2: Peri<'static, GPDMA1_CH2>

GPDMA1_CH2 peripheral

GPDMA1_CH3: Peri<'static, GPDMA1_CH3>

GPDMA1_CH3 peripheral

GPDMA1_CH4: Peri<'static, GPDMA1_CH4>

GPDMA1_CH4 peripheral

GPDMA1_CH5: Peri<'static, GPDMA1_CH5>

GPDMA1_CH5 peripheral

GPDMA1_CH6: Peri<'static, GPDMA1_CH6>

GPDMA1_CH6 peripheral

GPDMA1_CH7: Peri<'static, GPDMA1_CH7>

GPDMA1_CH7 peripheral

GPDMA1_CH8: Peri<'static, GPDMA1_CH8>

GPDMA1_CH8 peripheral

GPDMA1_CH9: Peri<'static, GPDMA1_CH9>

GPDMA1_CH9 peripheral

GPDMA1_CH10: Peri<'static, GPDMA1_CH10>

GPDMA1_CH10 peripheral

GPDMA1_CH11: Peri<'static, GPDMA1_CH11>

GPDMA1_CH11 peripheral

GPDMA1_CH12: Peri<'static, GPDMA1_CH12>

GPDMA1_CH12 peripheral

GPDMA1_CH13: Peri<'static, GPDMA1_CH13>

GPDMA1_CH13 peripheral

GPDMA1_CH14: Peri<'static, GPDMA1_CH14>

GPDMA1_CH14 peripheral

GPDMA1_CH15: Peri<'static, GPDMA1_CH15>

GPDMA1_CH15 peripheral

Implementations

Source

impl Peripherals

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that youโ€™re only using one instance of this type at a time.